import React, { useState, useEffect } from "react";
import Calendar from "react-calendar";
import "react-calendar/dist/Calendar.css";
import "./styles.css";
import ConfirmationPopup from "./ConfirmationPopup";

const timeSlots = [
  "10:00 AM",
  "10:15 AM",
  "10:30 AM",
  "10:45 AM",
  "11:00 AM",
  "11:15 AM",
  "11:30 AM",
  "11:45 AM",
  "12:00 PM",
  "12:15 PM",
  "12:30 PM",
  "12:45 PM",
  "01:00 PM",
  "01:15 PM",
  "01:30 PM",
  "01:45 PM",
  "02:00 PM",
  "02:15 PM",
  "02:30 PM",
  "02:45 PM",
  "03:00 PM",
  "03:15 PM",
  "03:30 PM",
  "03:45 PM",
  "04:00 PM",
  "04:15 PM",
  "04:30 PM",
  "04:45 PM",
  "05:00 PM",
  "05:15 PM",
  "05:30 PM",
  "05:45 PM",
  "06:00 PM",
  "06:15 PM",
  "06:30 PM",
  "06:45 PM",
  "07:00 PM",
  "07:15 PM",
  "07:30 PM",
  "07:45 PM",
  "08:00 PM",
  "08:15 PM",
  "08:30 PM",
  "08:45 PM",
  "09:00 PM",
  "09:15 PM",
  "09:30 PM",
  "09:45 PM",
  "10:00 PM",
  "10:15 PM",
  "10:30 PM",
  "10:45 PM",
  "11:00 PM",
  "11:15 PM",
  "11:30 PM",
  "11:45 PM",
];

const CalendarPopup = ({ onClose }) => {
  const [selectedDate, setSelectedDate] = useState(new Date());
  const [selectedTime, setSelectedTime] = useState(() => {
    const now = new Date();
    const hours = now.getHours() % 12 || 12;
    const minutes = now.getMinutes();
    const ampm = now.getHours() >= 12 ? "PM" : "AM";
    return `${hours.toString().padStart(2, "0")}:${minutes
      .toString()
      .padStart(2, "0")} ${ampm}`;
  });
  const [showConfirmation, setShowConfirmation] = useState(false);

  const formatDay = (date) => {
    const options = { weekday: "long" };
    return date.toLocaleDateString(undefined, options);
  };

  const formatNumericDate = (date) => {
    const options = { day: "numeric" };
    return date.toLocaleDateString(undefined, options);
  };

  const handleSubmit = () => {
    console.log("Selected Date:", selectedDate);
    console.log("Selected Time:", selectedTime);
    setShowConfirmation(true);
  };

  const handleCloseConfirmation = () => {
    setShowConfirmation(false);
    onClose();
  };

  return (
    <>
      <div className="fixed inset-0 flex items-center justify-center z-50 bg-black bg-opacity-50">
        <div className="bg-[#8D7C3B] borderTopRadius borderBottomRadius w-auto">
          <div className="flex gap-5 w-full justify-center">
            <div className="flex flex-col justify-evenly items-center w-[200px]">
              <div className="flex flex-col items-center gap-0">
                <div className="text-[36px] text-white font-semibold">
                  {formatDay(selectedDate)}
                </div>
                <div className="text-[55px] text-white font-semibold">
                  {formatNumericDate(selectedDate)}
                </div>
              </div>
              <div className="flex flex-col items-center gap-2">
                <select
                  value={selectedTime}
                  onChange={(e) => setSelectedTime(e.target.value)}
                  className="mt-2 py-1 px-3 text-[#8D7C3B] bg-[#FFFFFF] cursor-pointer rounded-[4px]"
                >
                  {timeSlots.map((slot, index) => (
                    <option key={index} value={slot}>
                      {slot}
                    </option>
                  ))}
                </select>
                <button
                  onClick={handleSubmit}
                  className="text-[14px] mt-2 py-1 px-3 text-[#fff] border-2 border-[#FFFFFF] cursor-pointer rounded-[4px]"
                >
                  Submit
                </button>
              </div>
            </div>
            <div className="flex-grow relative">
              <Calendar
                onChange={setSelectedDate}
                value={selectedDate}
                className="w-full h-[322px] rounded-tl-[24px] rounded-bl-[24px]"
              />
              <button
                onClick={onClose}
                className="text-red-500 absolute top-3 right-3"
              >
                <img src="/icons/golden-cross.svg" alt="" />
              </button>
            </div>
          </div>
        </div>
      </div>
      {showConfirmation && (
        <ConfirmationPopup onClose={handleCloseConfirmation} />
      )}
    </>
  );
};

export default CalendarPopup;
